.. currentmodule:: opics

Public API: opics package
=========================


:code:`components` types
------------------------

.. autosummary::
   components.componentModel
   components.compoundElement
   components.Waveguide




:code:`opics.components` module
-------------------------------

.. automodule:: opics.components
   :members:
   :undoc-members:
   :show-inheritance:

opics.network module
--------------------

.. automodule:: opics.network
   :members:
   :undoc-members:
   :show-inheritance:

opics.sparam\_ops module
------------------------

.. automodule:: opics.sparam_ops
   :members:
   :undoc-members:
   :show-inheritance:

opics.utils module
------------------

.. automodule:: opics.utils
   :members:
   :undoc-members:
   :show-inheritance:

